@@ -13,12 +13,11 @@
 #' @import stats
 #' @importFrom xfun attr in_dir read_utf8 write_utf8 is_windows is_macos
 #'   file_exists dir_exists file_ext msg_cat dir_create del_empty_dir proc_kill
-#'   set_envvar exit_call
+#'   set_envvar exit_call existing_files
 #' @examples if (interactive()) blogdown::new_site()
 NULL
 
 with_ext = function(...) xfun::with_ext(...)
-existing_files = bookdown:::existing_files
 fetch_yaml = function(f) bookdown:::fetch_yaml(read_utf8(f))
 
 `%n%` = knitr:::`%n%`
